@@ -17,10 +17,6 @@ G_BEGIN_DECLS
 #define EPHY_TYPE_URI_CHECK_TYPE ad_uri_check_type_get_type()
 GType ad_uri_check_type_get_type (void);
 
-/* --- ephy-embed-event.h --- */
-#define EPHY_TYPE_EMBED_EVENT_CONTEXT ephy_embed_event_context_get_type()
-GType ephy_embed_event_context_get_type (void);
-
 /* --- ephy-embed-persist.h --- */
 #define EPHY_TYPE_EMBED_PERSIST_FLAGS ephy_embed_persist_flags_get_type()
 GType ephy_embed_persist_flags_get_type (void);
@@ -36,8 +32,6 @@ GType ephy_web_view_navigation_flags_get_type (void);
 GType ephy_web_view_net_state_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_CHROME ephy_web_view_chrome_get_type()
 GType ephy_web_view_chrome_get_type (void);
-#define EPHY_TYPE_WEB_VIEW_PRINT_PREVIEW_NAV_TYPE ephy_web_view_print_preview_nav_type_get_type()
-GType ephy_web_view_print_preview_nav_type_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_SECURITY_LEVEL ephy_web_view_security_level_get_type()
 GType ephy_web_view_security_level_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_DOCUMENT_TYPE ephy_web_view_document_type_get_type()
