@@ -1,6 +1,10 @@
 
 /* Generated data (by glib-mkenums) */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error Only <epiphany/epiphany.h> can be included directly.
+#endif
+
 #ifndef EPHY_TYPE_BUILTINS_H
 #define EPHY_TYPE_BUILTINS_H 1
 
